/*
 * Copyright (c) 2018 Nordic Semiconductor ASA
 *
 * SPDX-License-Identifier: LicenseRef-Nordic-5-Clause
 */

/** @file
 *  @brief LED Button Service (LBS) sample
 */

#include <zephyr/types.h>
#include <stddef.h>
#include <string.h>
#include <errno.h>
#include <sys/printk.h>
#include <sys/byteorder.h>
#include <zephyr.h>

#include <bluetooth/bluetooth.h>
#include <bluetooth/hci.h>
#include <bluetooth/conn.h>
#include <bluetooth/uuid.h>
#include <bluetooth/gatt.h>

#include <bluetooth/services/demo_service.h>

#include <logging/log.h>

LOG_MODULE_REGISTER(bt_ds, CONFIG_BT_DS_LOG_LEVEL);

static bool                   notify_enabled;
static struct bt_ds_cb        ds_cb;

static void lbslc_ccc_cfg_changed(const struct bt_gatt_attr *attr,
				  uint16_t value)
{
	notify_enabled = (value == BT_GATT_CCC_NOTIFY);
}

static ssize_t read_count(struct bt_conn *conn,
			  const struct bt_gatt_attr *attr,
			  void *buf,
			  uint16_t len,
			  uint16_t offset)
{
	LOG_DBG("Attribute read (count), handle: %u, conn: %p", attr->handle,
		(void *)conn);

      	if (ds_cb.count_cb) {

          const char *value = ds_cb.count_cb();
          const uint16_t read_len = len >= 1 ? 1 : 0;

          return bt_gatt_attr_read(conn, attr, buf, read_len, offset, value,
					 sizeof(*value));
        }


	return 0;
}


/*  Demo Service Declaration */
BT_GATT_SERVICE_DEFINE(ds_svc,
BT_GATT_PRIMARY_SERVICE(BT_UUID_DS),
	BT_GATT_CHARACTERISTIC(BT_UUID_DS_COUNT,
			       BT_GATT_CHRC_READ,
			       BT_GATT_PERM_READ, read_count, NULL, NULL),
	BT_GATT_CCC(lbslc_ccc_cfg_changed,
		    BT_GATT_PERM_READ | BT_GATT_PERM_WRITE),
);

int bt_ds_init(struct bt_ds_cb *callbacks)
{	

	if (callbacks) {
                ds_cb.count_cb   = callbacks->count_cb;
	}
	
        return 0;
}
